define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "toto čtvrtletí",
	"field-quarter-short-relative+1": "příští čtvrtletí",
	"field-tue-relative+-1": "minulé úterý",
	"field-year": "rok",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "tuto středu",
	"field-wed-relative+1": "příští středu",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "minuta",
	"field-month-narrow-relative+-1": "minulý měs.",
	"field-tue-narrow-relative+0": "toto úterý",
	"field-tue-narrow-relative+1": "příští úterý",
	"field-day-short-relative+-1": "včera",
	"field-thu-short-relative+0": "tento čtvrtek",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "dnes",
	"field-day-short-relative+-2": "předevčírem",
	"field-thu-short-relative+1": "příští čtvrtek",
	"field-day-relative+1": "zítra",
	"field-week-narrow-relative+0": "tento týd.",
	"field-day-relative+2": "pozítří",
	"field-week-narrow-relative+1": "příští týd.",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-wed-narrow-relative+-1": "minulou středu",
	"field-year-narrow": "r.",
	"field-era-short": "letop.",
	"field-year-narrow-relative+0": "tento rok",
	"field-tue-relative+0": "toto úterý",
	"field-year-narrow-relative+1": "příští rok",
	"field-tue-relative+1": "příští úterý",
	"field-weekdayOfMonth": "den týdne v měsíci",
	"field-second-short": "s",
	"dateFormatItem-MMMd": "d. M.",
	"field-weekdayOfMonth-narrow": "d. týd. v měs.",
	"field-week-relative+0": "tento týden",
	"field-month-relative+0": "tento měsíc",
	"field-week-relative+1": "příští týden",
	"field-month-relative+1": "příští měsíc",
	"field-sun-narrow-relative+0": "tuto neděli",
	"field-mon-short-relative+0": "toto pondělí",
	"field-sun-narrow-relative+1": "příští neděli",
	"field-mon-short-relative+1": "příští pondělí",
	"field-second-relative+0": "nyní",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"field-weekOfMonth": "týden v měsíci",
	"field-month-short": "měs.",
	"dateFormatItem-GyMMMEd": "E d. M. y G",
	"dateFormatItem-yyyyMd": "d. M. y GGGGG",
	"field-day": "den",
	"field-dayOfYear-short": "den v r.",
	"field-year-relative+-1": "minulý rok",
	"field-sat-short-relative+-1": "minulou sobotu",
	"dateFormatItem-yyyyMMMMd": "d. MMMM y G",
	"field-hour-relative+0": "tuto hodinu",
	"dateFormatItem-yyyyMEd": "E d. M. y GGGGG",
	"field-second-short-relative+0": "nyní",
	"field-wed-relative+-1": "minulou středu",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "minulou sobotu",
	"field-second": "sekunda",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-GyMMMd": "d. M. y G",
	"field-hour-short-relative+0": "tuto hodinu",
	"field-quarter": "čtvrtletí",
	"field-week-short": "týd.",
	"field-day-narrow-relative+0": "dnes",
	"field-day-narrow-relative+1": "zítra",
	"field-day-narrow-relative+2": "pozítří",
	"dateFormatItem-yyyyMMMMEd": "E d. MMMM y G",
	"field-tue-short-relative+0": "toto úterý",
	"field-tue-short-relative+1": "příští úterý",
	"field-month-short-relative+-1": "minulý měs.",
	"field-mon-relative+-1": "minulé pondělí",
	"dateFormatItem-GyMMM": "LLLL y G",
	"field-month": "měsíc",
	"field-day-narrow": "den",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "min",
	"field-dayperiod": "část dne",
	"field-sat-short-relative+0": "tuto sobotu",
	"field-sat-short-relative+1": "příští sobotu",
	"dateFormat-medium": "d. M. y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-yyyyM": "M/y GGGGG",
	"field-second-narrow": "s",
	"field-mon-relative+0": "toto pondělí",
	"field-day-narrow-relative+-1": "včera",
	"field-year-short": "r.",
	"field-mon-relative+1": "příští pondělí",
	"field-day-narrow-relative+-2": "předevčírem",
	"field-quarter-relative+-1": "minulé čtvrtletí",
	"dateFormatItem-yyyyMMMd": "d. M. y G",
	"field-dayperiod-narrow": "část d.",
	"field-week-narrow-relative+-1": "minulý týd.",
	"field-dayOfYear": "den v roce",
	"field-sat-relative+-1": "minulou sobotu",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "d. M.",
	"field-hour": "hodina",
	"field-minute-narrow-relative+0": "tuto minutu",
	"dateFormat-full": "EEEE d. MMMM y G",
	"field-month-relative+-1": "minulý měsíc",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "Q",
	"field-sat-narrow-relative+0": "tuto sobotu",
	"field-fri-relative+0": "tento pátek",
	"field-sat-narrow-relative+1": "příští sobotu",
	"field-fri-relative+1": "příští pátek",
	"dateFormatItem-EBhm": "E h:mm B",
	"field-month-narrow-relative+0": "tento měs.",
	"field-month-narrow-relative+1": "příští měs.",
	"field-sun-short-relative+0": "tuto neděli",
	"field-sun-short-relative+1": "příští neděli",
	"field-week-relative+-1": "minulý týden",
	"field-quarter-short-relative+-1": "minulé čtvrtletí",
	"dateFormatItem-Ehm": "E h:mm a",
	"field-minute-short-relative+0": "tuto minutu",
	"field-quarter-relative+0": "toto čtvrtletí",
	"field-minute-relative+0": "tuto minutu",
	"field-quarter-relative+1": "příští čtvrtletí",
	"field-wed-short-relative+-1": "minulou středu",
	"dateFormat-short": "dd.MM.yy GGGGG",
	"dateFormatItem-Bh": "h B",
	"field-year-narrow-relative+-1": "minulý rok",
	"field-thu-short-relative+-1": "minulý čtvrtek",
	"dateFormatItem-yyyyMMMEd": "E d. M. y G",
	"field-mon-narrow-relative+-1": "minulé pondělí",
	"dateFormatItem-MMMMd": "d. MMMM",
	"field-thu-narrow-relative+-1": "minulý čtvrtek",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H",
	"field-weekOfMonth-short": "týd. v m.",
	"field-tue-narrow-relative+-1": "minulé úterý",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "tuto středu",
	"field-wed-short-relative+1": "příští středu",
	"field-sun-relative+-1": "minulou neděli",
	"dateFormatItem-MMMMEd": "E d. MMMM",
	"dateTimeFormat-full": "{1} {0}",
	"field-second-narrow-relative+0": "nyní",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-d": "d.",
	"field-weekday": "den v týdnu",
	"field-day-short-relative+0": "dnes",
	"field-quarter-narrow-relative+0": "toto čtvrtletí",
	"field-day-short-relative+1": "zítra",
	"field-sat-relative+0": "tuto sobotu",
	"field-quarter-narrow-relative+1": "příští čtvrtletí",
	"dateFormatItem-h": "h a",
	"field-day-short-relative+2": "pozítří",
	"field-sat-relative+1": "příští sobotu",
	"field-week-short-relative+0": "tento týd.",
	"field-week-short-relative+1": "příští týd.",
	"dateFormatItem-GyMMMMEd": "E d. MMMM y G",
	"field-dayOfYear-narrow": "d. v r.",
	"field-month-short-relative+0": "tento měs.",
	"field-month-short-relative+1": "příští měs.",
	"field-weekdayOfMonth-short": "den týd. v měs.",
	"dateFormatItem-MEd": "E d. M.",
	"field-zone-narrow": "pásmo",
	"dateFormatItem-y": "y G",
	"field-thu-narrow-relative+0": "tento čtvrtek",
	"field-sun-narrow-relative+-1": "minulou neděli",
	"field-mon-short-relative+-1": "minulé pondělí",
	"field-thu-narrow-relative+1": "příští čtvrtek",
	"field-thu-relative+0": "tento čtvrtek",
	"field-thu-relative+1": "příští čtvrtek",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-fri-short-relative+-1": "minulý pátek",
	"field-thu-relative+-1": "minulý čtvrtek",
	"field-week": "týden",
	"dateFormatItem-Ed": "E d.",
	"field-wed-narrow-relative+0": "tuto středu",
	"field-wed-narrow-relative+1": "příští středu",
	"field-quarter-narrow-relative+-1": "minulé čtvrtletí",
	"field-year-short-relative+0": "tento rok",
	"dateFormatItem-yyyyMMM": "LLLL y G",
	"field-dayperiod-short": "část dne",
	"field-year-short-relative+1": "příští rok",
	"field-fri-short-relative+0": "tento pátek",
	"field-fri-short-relative+1": "příští pátek",
	"field-week-short-relative+-1": "minulý týd.",
	"dateFormatItem-GyMMMMd": "d. MMMM y G",
	"field-hour-narrow-relative+0": "tuto hodinu",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-hour-short": "h",
	"field-zone-short": "čas. pásmo",
	"field-month-narrow": "měs.",
	"field-hour-narrow": "h",
	"field-fri-narrow-relative+-1": "minulý pátek",
	"field-year-relative+0": "tento rok",
	"field-year-relative+1": "příští rok",
	"field-era-narrow": "let.",
	"field-fri-relative+-1": "minulý pátek",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-tue-short-relative+-1": "minulé úterý",
	"field-minute-narrow": "min",
	"field-mon-narrow-relative+0": "toto pondělí",
	"dateFormatItem-EHm": "E H:mm",
	"field-mon-narrow-relative+1": "příští pondělí",
	"field-year-short-relative+-1": "minulý rok",
	"field-zone": "časové pásmo",
	"dateFormatItem-MMMEd": "E d. M.",
	"field-weekOfMonth-narrow": "týd. v m.",
	"dateFormatItem-EHms": "E H:mm:ss",
	"field-weekday-narrow": "d. v týd.",
	"field-quarter-narrow": "Q",
	"field-sun-short-relative+-1": "minulou neděli",
	"field-day-relative+-1": "včera",
	"field-day-relative+-2": "předevčírem",
	"field-weekday-short": "den v týd.",
	"dateFormatItem-Bhm": "h:mm B",
	"field-sun-relative+0": "tuto neděli",
	"field-sun-relative+1": "příští neděli",
	"dateFormatItem-Gy": "y G",
	"field-day-short": "den",
	"field-week-narrow": "týd.",
	"field-era": "letopočet",
	"field-fri-narrow-relative+0": "tento pátek",
	"field-fri-narrow-relative+1": "příští pátek"
}
//end v1.x content
);